
############################## Script for diary study in adults with type 2 diabetes
##############################last update: 26.04.2021

### libraries and settings

library(foreign)
library(car)
library(lme4)
library(lmerTest)
library(MASS)
library(nlme)
library(effects)
library(ggplot2)
library(psych)
library(MuMIn)
options(scipen=999)

## importing the data in R
diary_diabetes_long = read.spss("data_diary_long.sav", to.data.frame=TRUE)  
diary_diabetes_wide = read.spss("Baseline_info_wide_format.sav", to.data.frame=TRUE) 
diary_diabetes_baseline <- diary_diabetes_wide[,c("ID","Retired","promis_anxiety_total","promis_depression_total")]
diary_diabetes <- merge(diary_diabetes_long,diary_diabetes_baseline, by.x='ID', by.y='ID')

diary_diabetes$ID <- as.factor(diary_diabetes$ID)


# 2 categories instead of 5 for education

diary_diabetes$Education_2 <- ifelse(diary_diabetes$Education==c("primary education"),c("low"),
                                     ifelse(diary_diabetes$Education==c("secondary education (lower)"),c("low"),
                                            ifelse(diary_diabetes$Education==c("secondary education (higher)"),c("low"),
                                                   c("high"))))
diary_diabetes$Education_2 <- factor(diary_diabetes$Education_2)


#retired as factor
diary_diabetes$Retired <- as.factor(diary_diabetes$Retired)



##### dataset with accelerometer days >3 and diary days >6

# selecting correct accelerometer days (= 10 hours or more wear time)
diary_diabetes$wear_time <- diary_diabetes$Barrett_sedentary + diary_diabetes$Barrett_light + diary_diabetes$Barrett_mvpa
diary_diabetes$wear_time_correct <- ifelse(diary_diabetes$wear_time > 599.9, 1,0)
total_accelerometer_days <- aggregate(diary_diabetes$wear_time_correct, by=list(diary_diabetes$ID), sum, na.rm = T)
names(total_accelerometer_days) <- c('ID', 'total_accelerometer_days')
diary_diabetes <- merge(diary_diabetes,total_accelerometer_days, by='ID')


# selecting correct diary days (i.e. when people filled out the morning diary at the correct time)
diary_diabetes$day_correct <- ifelse(diary_diabetes$time_morning_ok== "OK", diary_diabetes$Day_adapted,NA)
diary_diabetes$diary_data <- !is.na(diary_diabetes$day_correct)
total_diary_days <- aggregate(diary_diabetes$diary_data, by=list(diary_diabetes$ID), sum)
names(total_diary_days) <- c('ID', 'total_diary_days')
diary_diabetes <- merge(diary_diabetes,total_diary_days, by='ID')

diary_diabetes_excluded <- diary_diabetes[which(diary_diabetes$total_accelerometer_days<4 | diary_diabetes$total_diary_days<7),]
diary_diabetes <- diary_diabetes[which(diary_diabetes$total_accelerometer_days>3 & diary_diabetes$total_diary_days>6),]

## comparing demographics of included and excluded participants (based on accelerometer and diary data)

test_age_included <- aggregate(diary_diabetes$Age,list(diary_diabetes$ID),mean)
summary(test_age_included)
sd(test_age_included$x, na.rm = T)
test_age_excluded <- aggregate(diary_diabetes_excluded$Age,list(diary_diabetes_excluded$ID),mean)
summary(test_age_excluded)
sd(test_age_excluded$x, na.rm = T)

test_waist_included <- aggregate(diary_diabetes$waist_circumference,list(diary_diabetes$ID),mean)
summary(test_waist_included)
sd(test_waist_included$x)
test_waist_excluded <- aggregate(diary_diabetes_excluded$waist_circumference,list(diary_diabetes_excluded$ID),mean)
summary(test_waist_excluded)
sd(test_waist_excluded$x)

test_bmi_included<- aggregate(diary_diabetes$BMI,list(diary_diabetes$ID),mean)
summary(test_bmi_included)
sd(test_bmi_included$x, na.rm=T)
test_bmi_excluded<- aggregate(diary_diabetes_excluded$BMI,list(diary_diabetes_excluded$ID),mean)
summary(test_bmi_excluded)
sd(test_bmi_excluded$x, na.rm=T)

test_diagnosis_included <- aggregate(diary_diabetes$Time_diagnosis,list(diary_diabetes$ID),mean)
summary(test_diagnosis_included)
sd(test_diagnosis_included$x, na.rm=T)
test_diagnosis_excluded <- aggregate(diary_diabetes_excluded$Time_diagnosis,list(diary_diabetes_excluded$ID),mean)
summary(test_diagnosis_excluded)
sd(test_diagnosis_excluded$x, na.rm=T)

test_promis_anxiety_included <- aggregate(diary_diabetes$promis_anxiety_total,list(diary_diabetes$ID),mean)
summary(test_promis_anxiety_included)
sd(test_promis_anxiety_included$x)
test_promis_anxiety_excluded <- aggregate(diary_diabetes_excluded$promis_anxiety_total,list(diary_diabetes_excluded$ID),mean)
summary(test_promis_anxiety_excluded)
sd(test_promis_anxiety_excluded$x)

test_promis_depression_included <- aggregate(diary_diabetes$promis_depression_total,list(diary_diabetes$ID),mean)
summary(test_promis_depression_included)
sd(test_promis_depression_included$x)
test_promis_depression_excluded <- aggregate(diary_diabetes_excluded$promis_depression_total,list(diary_diabetes_excluded$ID),mean)
summary(test_promis_depression_excluded)
sd(test_promis_depression_excluded$x)

table(diary_diabetes$Gender,diary_diabetes$ID) 
table(diary_diabetes_excluded$Gender,diary_diabetes_excluded$ID) 

table(diary_diabetes$Education_2,diary_diabetes$ID) 
table(diary_diabetes_excluded$Education_2,diary_diabetes_excluded$ID) 

table(diary_diabetes$Retired, diary_diabetes$ID) 
table(diary_diabetes_excluded$Retired, diary_diabetes_excluded$ID) 


# controlling PA levels for wear time 

diary_diabetes$Barrett_sedentary_percentage <- ifelse(diary_diabetes$wear_time_correct == 1, (diary_diabetes$Barrett_sedentary / diary_diabetes$wear_time) * 100, NA )
diary_diabetes$Barrett_light_percentage <- ifelse(diary_diabetes$wear_time_correct == 1,(diary_diabetes$Barrett_light / diary_diabetes$wear_time) * 100, NA)
diary_diabetes$Barrett_mvpa_percentage <- ifelse(diary_diabetes$wear_time_correct == 1,(diary_diabetes$Barrett_mvpa / diary_diabetes$wear_time) * 100, NA)


##checking for outliers

summary(diary_diabetes$Age)
summary(diary_diabetes$Gender)
summary(diary_diabetes$Education_2)
summary(diary_diabetes$BMI)
summary(diary_diabetes$waist_circumference)

summary(diary_diabetes$tired)
summary(diary_diabetes$tension_stress)
summary(diary_diabetes$pain)
summary(diary_diabetes$nausea_dizziness)
summary(diary_diabetes$numbness)
summary(diary_diabetes$sadness)

diary_diabetes_wear_time_correct <- diary_diabetes[diary_diabetes$wear_time_correct==1,]
summary(diary_diabetes_wear_time_correct$wear_time)
summary(diary_diabetes$Barrett_sedentary)
summary(diary_diabetes$Barrett_light)
summary(diary_diabetes$Barrett_mvpa)
summary(diary_diabetes$Barrett_sedentary_percentage)
summary(diary_diabetes$Barrett_light_percentage)
summary(diary_diabetes$Barrett_mvpa_percentage)



# creating within subject and between subject variables for the stressors

mean_tired <- aggregate(diary_diabetes$tired, by=list(diary_diabetes$ID), mean, na.rm=T)
mean_stress <- aggregate(diary_diabetes$tension_stress, by=list(diary_diabetes$ID), mean, na.rm=T)
mean_pain <- aggregate(diary_diabetes$pain, by=list(diary_diabetes$ID), mean, na.rm=T)
mean_nausea <- aggregate(diary_diabetes$nausea_dizziness, by=list(diary_diabetes$ID), mean, na.rm=T)
mean_numbness <- aggregate(diary_diabetes$numbness, by=list(diary_diabetes$ID), mean, na.rm=T)
mean_sadness <- aggregate(diary_diabetes$sadness, by=list(diary_diabetes$ID), mean, na.rm=T)


names(mean_tired) <- c('ID', 'mean_tired')
names(mean_stress) <- c('ID', 'mean_stress')
names(mean_pain) <- c('ID', 'mean_pain')
names(mean_nausea) <- c('ID', 'mean_nausea')
names(mean_numbness) <- c('ID', 'mean_numbness')
names(mean_sadness) <- c('ID', 'mean_sadness')


diary_diabetes <- merge(diary_diabetes,mean_tired, by='ID')
diary_diabetes <- merge(diary_diabetes,mean_stress, by='ID')
diary_diabetes <- merge(diary_diabetes,mean_pain, by='ID')
diary_diabetes <- merge(diary_diabetes,mean_nausea, by='ID')
diary_diabetes <- merge(diary_diabetes,mean_numbness, by='ID')
diary_diabetes <- merge(diary_diabetes,mean_sadness, by='ID')



##center predictors at level 1 around the individual's mean value

diary_diabetes$tired_center <- diary_diabetes$tired - diary_diabetes$mean_tired
diary_diabetes$stress_center <- diary_diabetes$tension_stress - diary_diabetes$mean_stress
diary_diabetes$pain_center <- diary_diabetes$pain - diary_diabetes$mean_pain
diary_diabetes$nausea_center <- diary_diabetes$nausea_dizziness - diary_diabetes$mean_nausea
diary_diabetes$numbness_center <- diary_diabetes$numbness - diary_diabetes$mean_numbness
diary_diabetes$sadness_center <- diary_diabetes$sadness - diary_diabetes$mean_sadness



##scaling 

diary_diabetes$Age_scale <- scale(diary_diabetes$Age)
diary_diabetes$BMI_scale <- scale(diary_diabetes$BMI)
diary_diabetes$waist_circumference_scale <- scale(diary_diabetes$waist_circumference)
diary_diabetes$Time_diagnosis_scale <- scale(diary_diabetes$Time_diagnosis)
diary_diabetes$promis_anxiety_total_scale <- scale(diary_diabetes$promis_anxiety_total)
diary_diabetes$promis_depression_total_scale <- scale(diary_diabetes$promis_depression_total)


## select complete data

diary_diabetes_complete <- diary_diabetes[complete.cases(diary_diabetes[,c("Age","waist_circumference","promis_anxiety_total","promis_depression_total","Gender","Education_2","Retired")]),]



###### Descriptive statistics

test_accelerometer_days <- aggregate(diary_diabetes_complete$total_accelerometer_days ,list(diary_diabetes_complete$ID),mean)
summary(test_accelerometer_days)
sd(test_accelerometer_days$x)

test_diary_days <- aggregate(diary_diabetes_complete$total_diary_days ,list(diary_diabetes_complete$ID),mean)
summary(test_diary_days)
sd(test_diary_days$x)


test_age <- aggregate(diary_diabetes_complete$Age,list(diary_diabetes_complete$ID),mean)
summary(test_age)
sd(test_age$x)

test_waist <- aggregate(diary_diabetes_complete$waist_circumference,list(diary_diabetes_complete$ID),mean)
summary(test_waist)
sd(test_waist$x)

test_bmi <- aggregate(diary_diabetes_complete$BMI,list(diary_diabetes_complete$ID),mean)
summary(test_bmi)
sd(test_bmi$x, na.rm=T)

test_diagnosis <- aggregate(diary_diabetes_complete$Time_diagnosis,list(diary_diabetes_complete$ID),mean)
summary(test_diagnosis)
sd(test_diagnosis$x, na.rm=T)

test_promis_anxiety <- aggregate(diary_diabetes_complete$promis_anxiety_total,list(diary_diabetes_complete$ID),mean)
summary(test_promis_anxiety)
sd(test_promis_anxiety$x)

test_promis_depression <- aggregate(diary_diabetes_complete$promis_depression_total,list(diary_diabetes_complete$ID),mean)
summary(test_promis_depression)
sd(test_promis_depression$x)

test_wear_time <- aggregate(diary_diabetes_wear_time_correct$wear_time,list(diary_diabetes_wear_time_correct$ID),mean)


table(diary_diabetes_complete$Gender,diary_diabetes_complete$ID) #13 women
13/38

table(diary_diabetes_complete$Education_2,diary_diabetes_complete$ID) #20 high level of education
20/38

table(diary_diabetes_complete$Retired, diary_diabetes_complete$ID) # 19 retired
19/38


descript_mean_tired <- aggregate(diary_diabetes_complete$tired, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(descript_mean_tired) <- c('ID', 'descript_mean_tired')
mean(descript_mean_tired$descript_mean_tired)
sd(descript_mean_tired$descript_mean_tired)
range(descript_mean_tired$descript_mean_tired)

descript_mean_stress <- aggregate(diary_diabetes_complete$tension_stress, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(descript_mean_stress) <- c('ID', 'descript_mean_stress')
mean(descript_mean_stress$descript_mean_stress)
sd(descript_mean_stress$descript_mean_stress)
range(descript_mean_stress$descript_mean_stress)

descript_mean_pain <- aggregate(diary_diabetes_complete$pain, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(descript_mean_pain) <- c('ID', 'descript_mean_pain')
mean(descript_mean_pain$descript_mean_pain)
sd(descript_mean_pain$descript_mean_pain)
range(descript_mean_pain$descript_mean_pain)

descript_mean_nausea <- aggregate(diary_diabetes_complete$nausea_dizziness, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(descript_mean_nausea) <- c('ID', 'descript_mean_nausea')
mean(descript_mean_nausea$descript_mean_nausea)
sd(descript_mean_nausea$descript_mean_nausea)
range(descript_mean_nausea$descript_mean_nausea)

descript_mean_tingling <- aggregate(diary_diabetes_complete$numbness, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(descript_mean_tingling) <- c('ID', 'descript_mean_tingling')
mean(descript_mean_tingling$descript_mean_tingling)
sd(descript_mean_tingling$descript_mean_tingling)
range(descript_mean_tingling$descript_mean_tingling)

descript_mean_sad <- aggregate(diary_diabetes_complete$sadness, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(descript_mean_sad) <- c('ID', 'descript_mean_sad')
mean(descript_mean_sad$descript_mean_sad)
sd(descript_mean_sad$descript_mean_sad)
range(descript_mean_sad$descript_mean_sad)


mean_sedentary <- aggregate(diary_diabetes_complete$Barrett_sedentary, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(mean_sedentary) <- c('ID', 'mean_sedentary')
mean(mean_sedentary$mean_sedentary)
sd(mean_sedentary$mean_sedentary)
range(mean_sedentary$mean_sedentary)

mean_lpa <- aggregate(diary_diabetes_complete$Barrett_light, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(mean_lpa) <- c('ID', 'mean_lpa')
mean(mean_lpa$mean_lpa)
sd(mean_lpa$mean_lpa)
range(mean_lpa$mean_lpa)

mean_mvpa <- aggregate(diary_diabetes_complete$Barrett_mvpa, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(mean_mvpa) <- c('ID', 'mean_mvpa')
mean(mean_mvpa$mean_mvpa)
sd(mean_mvpa$mean_mvpa)
range(mean_mvpa$mean_mvpa)

mean_sedentary <- aggregate(diary_diabetes_complete$Barrett_sedentary_percentage, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(mean_sedentary) <- c('ID', 'mean_sedentary_percentage')
mean(mean_sedentary$mean_sedentary_percentage)
sd(mean_sedentary$mean_sedentary_percentage)
range(mean_sedentary$mean_sedentary_percentage)

mean_lpa <- aggregate(diary_diabetes_complete$Barrett_light_percentage, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(mean_lpa) <- c('ID', 'mean_lpa_percentage')
mean(mean_lpa$mean_lpa_percentage)
sd(mean_lpa$mean_lpa_percentage)
range(mean_lpa$mean_lpa_percentage)

mean_mvpa <- aggregate(diary_diabetes_complete$Barrett_mvpa_percentage, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(mean_mvpa) <- c('ID', 'mean_mvpa_percentage')
mean(mean_mvpa$mean_mvpa_percentage)
sd(mean_mvpa$mean_mvpa_percentage)
range(mean_mvpa$mean_mvpa_percentage)

## calculating the number of people reaching the PA guidelines
#Barrett
sum_mvpa <- aggregate(diary_diabetes_complete$Barrett_mvpa, by=list(diary_diabetes_complete$ID), sum, na.rm=T)
names(sum_mvpa) <- c('ID', 'sum_mvpa')
valid_accelerometer_days <- aggregate(diary_diabetes_complete$total_accelerometer_days, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(valid_accelerometer_days) <- c('ID', 'valid_accelerometer_days')
guidelines <- cbind(sum_mvpa,valid_accelerometer_days)
guidelines$weekly <- (guidelines$sum_mvpa / guidelines$valid_accelerometer_days)*7

#Freedson
sum_mvpa_Freedson <- aggregate(diary_diabetes_complete$Freedson_mvpa, by=list(diary_diabetes_complete$ID), sum, na.rm=T)
names(sum_mvpa_Freedson) <- c('ID', 'sum_mvpa')
valid_accelerometer_days <- aggregate(diary_diabetes_complete$total_accelerometer_days, by=list(diary_diabetes_complete$ID), mean, na.rm=T)
names(valid_accelerometer_days) <- c('ID', 'valid_accelerometer_days')
guidelines_Freedson <- cbind(sum_mvpa_Freedson,valid_accelerometer_days)
guidelines_Freedson$weekly <- (guidelines_Freedson$sum_mvpa / guidelines_Freedson$valid_accelerometer_days)*7


## calculating between- and within-subject variance for the stressors

fit_fatigue <- lmer(tired~ 1 +(1|ID),data=diary_diabetes_complete)
summary(fit_fatigue)

fit_stress <- lmer(tension_stress~ 1 +(1|ID),data=diary_diabetes_complete)
summary(fit_stress)

fit_pain <- lmer(pain~ 1 +(1|ID),data=diary_diabetes_complete)
summary(fit_pain)

fit_nausea <- lmer(nausea_dizziness~ 1 +(1|ID),data=diary_diabetes_complete)
summary(fit_nausea)

fit_tingling <- lmer(numbness~ 1 +(1|ID),data=diary_diabetes_complete)
summary(fit_tingling)

fit_sadness <- lmer(sadness~ 1 +(1|ID),data=diary_diabetes_complete)
summary(fit_sadness)

fit_sedentary <- lmer(Barrett_sedentary_percentage~ 1 +(1|ID),data=diary_diabetes_complete)
summary(fit_sedentary)

fit_lpa <- lmer(Barrett_light_percentage~ 1 +(1|ID),data=diary_diabetes_complete)
summary(fit_lpa)

fit_mvpa <- lmer(Barrett_mvpa_percentage~ 1 +(1|ID),data=diary_diabetes_complete)
summary(fit_mvpa)



## visualizing the data through the day

diary_diabetes_complete$ID_recode <- as.integer(as.factor(diary_diabetes_complete$ID))

gg_tired <- ggplot(diary_diabetes_complete,aes(x=day_correct, y=tired, group=ID_recode))+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID_recode) +
  scale_y_continuous(breaks=c(2,4,6,8,10)) +
  scale_x_continuous(breaks=c(2,4,6,8,10)) +
  labs(x = "Days", y = "Fatigue") +
  theme_bw()
gg_tired

gg_pain <- ggplot(diary_diabetes_complete,aes(x=day_correct, y=pain, group=ID_recode))+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID_recode) +
  scale_y_continuous(breaks=c(2,4,6,8,10)) +
  scale_x_continuous(breaks=c(2,4,6,8,10)) +
  labs(x = "Days", y = "Pain") +
  theme_bw()
gg_pain

gg_stress <- ggplot(diary_diabetes_complete,aes(x=day_correct, y=tension_stress, group=ID_recode))+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID_recode) +
  scale_y_continuous(breaks=c(2,4,6,8,10)) +
  scale_x_continuous(breaks=c(2,4,6,8,10)) +
  labs(x = "Days", y = "Stress") +
  theme_bw()
gg_stress

gg_nausea <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= nausea_dizziness, group=ID_recode))+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID_recode) +
  scale_y_continuous(breaks=c(2,4,6,8,10)) +
  scale_x_continuous(breaks=c(2,4,6,8,10)) +
  labs(x = "Days", y = "Nausea/dizziness") +
  theme_bw()
gg_nausea

gg_neuropathy <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= numbness, group=ID_recode))+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID_recode) +
  scale_y_continuous(breaks=c(2,4,6,8,10)) +
  scale_x_continuous(breaks=c(2,4,6,8,10)) +
  labs(x = "Days", y = "Numbness/tingling") +
  theme_bw()
gg_neuropathy

gg_sad <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= sadness, group=ID_recode))+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID_recode) +
  scale_y_continuous(breaks=c(2,4,6,8,10)) +
  scale_x_continuous(breaks=c(2,4,6,8,10)) +
  labs(x = "Days", y = "Sadness") +
  theme_bw()
gg_sad

gg_freedson_sedentary <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= Freedson_sedentary, group=ID))+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID) +
  scale_y_continuous(breaks=c(2,4,6,8,10)) +
  theme_bw()

gg_freedson_light <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= Freedson_light, group=ID))+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID) +
  scale_y_continuous(breaks=c(2,4,6,8,10)) +
  theme_bw()

gg_freedson_mvpa <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= Freedson_mvpa, group=ID))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID) +
  theme_bw()

gg_barrett_sedentary <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= Barrett_sedentary, group=ID))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID) +
  theme_bw()

gg_barrett_light <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= Barrett_light, group=ID))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID) +
  theme_bw()

gg_barrett_mvpa <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= Barrett_mvpa, group=ID))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID) +
  theme_bw()

gg_barrett_sedentary_percentage <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= Barrett_sedentary_percentage, group=ID))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID) +
  theme_bw()

gg_barrett_light_percentage <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= Barrett_light_percentage, group=ID))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID) +
  theme_bw()

gg_barrett_mvpa_percentage <- ggplot(diary_diabetes_complete,aes(x=day_correct, y= Barrett_mvpa_percentage, group=ID))+
  geom_smooth(method = "lm", se = FALSE, color = "darkgrey")+
  geom_point(alpha = 0.3, size = 3) +
  facet_wrap(~ID) +
  theme_bw()

## building the multilevel models



# 1. BARRETT - sedentary time


barrett_sedentary_gauss <- lmer(Barrett_sedentary_percentage~ 
                                    tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                                    mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                                    Age_scale + Gender + waist_circumference_scale + Education_2 + Retired + promis_anxiety_total_scale + promis_depression_total_scale + 
                                    (1|ID), REML=T, data = diary_diabetes_complete)


#check model assumptions
  #constant variance + independence + linearity 
plot(barrett_sedentary_gauss)

  #normality
qqnorm(residuals(barrett_sedentary_gauss)) 
qqline(residuals(barrett_sedentary_gauss)) 


# summary of the model
summary(barrett_sedentary_gauss)

# confidence intervals
confint(barrett_sedentary_gauss)




# 2. BARRETT - physical activity at light intensity

barrett_lpa_gauss <- lmer(Barrett_light_percentage~ 
                              tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                              mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                              Age_scale + Gender + waist_circumference_scale + Education_2 + Retired + promis_anxiety_total_scale + promis_depression_total_scale + 
                              (1|ID), data = diary_diabetes_complete, REML=F)

#check model assumptions
  #constant variance + independence + linearity 
plot(barrett_lpa_gauss)

  #normality
qqnorm(residuals(barrett_lpa_gauss)) 
qqline(residuals(barrett_lpa_gauss)) 


# based on these plots: decided to fit and compare other models

library(optimx)


barrett_lpa_gamma_id <- glmer(Barrett_light_percentage~ 
                                tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                                mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                                Age_scale + Gender + waist_circumference_scale + Education_2 + Retired  +   promis_anxiety_total_scale + promis_depression_total_scale +
                                (1|ID), family = Gamma(link="identity"), data = diary_diabetes_complete,control=glmerControl(optimizer="nlminbwrap",optCtrl=list(maxfun=1000000)))

barrett_lpa_gamma_log <- glmer(Barrett_light_percentage~ 
                                tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                                mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                                Age_scale + Gender + waist_circumference_scale + Education_2 + Retired  +  promis_anxiety_total_scale + promis_depression_total_scale + 
                                (1|ID), family = Gamma(link="log"), data = diary_diabetes_complete,control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))

barrett_lpa_poiss <- glmer(Barrett_light_percentage~ 
                                 tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                                 mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                                 Age_scale + Gender + waist_circumference_scale + Education_2 + Retired  +  promis_anxiety_total_scale + promis_depression_total_scale + 
                                 (1|ID), family = poisson(link="log"), data = diary_diabetes_complete,control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))

barrett_lpa_nb <- glmer.nb(Barrett_light_percentage~ 
                              tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                              mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                              Age_scale + Gender + waist_circumference_scale + Education_2 + Retired + promis_anxiety_total_scale + promis_depression_total_scale + 
                              (1|ID), data = diary_diabetes_complete, control=glmerControl('optimx', optCtrl=list(method='L-BFGS-B'))) 

cbind(BIC(barrett_lpa_gauss), BIC(barrett_lpa_gamma_id), BIC(barrett_lpa_gamma_log), BIC(barrett_lpa_poiss))


#best fit for gamma_id

summary(barrett_lpa_gamma_id)

# confidence intervals

se <- sqrt(diag(vcov(barrett_lpa_gamma_id)))
(tab <- cbind(Est = fixef(barrett_lpa_gamma_id), LL = fixef(barrett_lpa_gamma_id) - 1.96 * se, UL = fixef(barrett_lpa_gamma_id) + 1.96 * se))



# 3. BARRETT - physical activity at moderate to vigorous intensity

barrett_mvpa_gauss <- lmer(Barrett_mvpa_percentage~ 
                             tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                             mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                             Age_scale + Gender + waist_circumference_scale + Education_2 + Retired + promis_anxiety_total_scale + promis_depression_total_scale + Time_diagnosis_scale +
                             (1|ID), data = diary_diabetes_complete, REML=F)

#check model assumptions
#constant variance + independence + linearity 
plot(barrett_mvpa_gauss)

#normality
qqnorm(residuals(barrett_mvpa_gauss)) 
qqline(residuals(barrett_mvpa_gauss)) 

# based on these plots: decided to fit and compare other models


barrett_mvpa_gamma_id <- glmer(Barrett_mvpa_percentage~ 
                                tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                                mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                                Age_scale + Gender + waist_circumference_scale + Education_2 + Retired + promis_anxiety_total_scale + promis_depression_total_scale + Time_diagnosis_scale +
                                (1|ID), family = Gamma(link="identity"), data = diary_diabetes_complete, control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))

barrett_mvpa_gamma_log <- glmer(Barrett_mvpa_percentage~ 
                                 tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                                 mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                                 Age_scale + Gender + waist_circumference_scale + Education_2 + Retired + promis_anxiety_total_scale + promis_depression_total_scale + Time_diagnosis_scale +
                                 (1|ID), family = Gamma(link="log"), data = diary_diabetes_complete, control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))

barrett_mvpa_poiss <- glmer(Barrett_mvpa_percentage~ 
                             tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                             mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                             Age_scale + Gender + waist_circumference_scale + Education_2 + Retired + promis_anxiety_total_scale + promis_depression_total_scale + Time_diagnosis_scale +
                             (1|ID), family = poisson(link="log"), data = diary_diabetes_complete, control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=100000)))

barrett_mvpa_nb <- glmer.nb(Barrett_mvpa_percentage~ 
                             tired_center + stress_center + pain_center + nausea_center + numbness_center + sadness_center +
                             mean_tired + mean_stress + mean_pain + mean_nausea + mean_numbness + mean_sadness +
                             Age_scale + Gender + waist_circumference_scale + Education_2 + Retired + promis_anxiety_total_scale + promis_depression_total_scale + Time_diagnosis_scale +
                             (1|ID), data = diary_diabetes_complete, control=glmerControl(optimizer ='optimx', optCtrl=list(method='nlminb'))) 
                               
                               
cbind(BIC(barrett_mvpa_gauss), BIC(barrett_mvpa_gamma_id), BIC(barrett_mvpa_gamma_log), BIC(barrett_mvpa_poiss)) 

# model with gamma id provides the best fit

summary(barrett_mvpa_gamma_id)

# confidence intervals

se <- sqrt(diag(vcov(barrett_mvpa_gamma_log)))
(tab <- cbind(Est = fixef(barrett_mvpa_gamma_log), LL = fixef(barrett_mvpa_gamma_log) - 1.96 * se, UL = fixef(barrett_mvpa_gamma_log) + 1.96 * se))





